##  Guidelines and Best Practices
  * Breadth before depth: Begin by identifying the various capabilities offered by your organization's technologies. For example, if you work with databases, you may have relational databases, NoSQL databases, and other types of databases.
  * Create categories: Once you have identified the technology capabilities, create corresponding categories within the tech category feature. These categories will serve as containers to group similar technologies. You can immediately start this by leveraging tech category data from the reference catalog and mapping your technology capabilities accordingly.
  * Use an IT capability model: Assign each technology to the appropriate category based on its capabilities. This will help maintain a clear and organized view of the technology landscape.
  * Don't overlap: Tech categories should be mutually exclusive and collectively exhaustive (MECE).


Example tech category: database
  * Tech category: relational database (for example, MySQL)
  * Tech category: NoSQL database (for example, MongoDB)
  * Tech category: graph database (for example, Neo4j)

![Example of a tech category grouping for databases.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743f3087a441014a50acb8bd7f57186_LowRes.png)
Here, the Database category groups different types of databases, making it simpler to manage and comprehend the technology inventory.
If using the TBM does not capture all the categories in your organization, for example, for accommodating the secret management, you can easily adapt, add, and modify the tech categories based on your needs.
